# Generated by Django 2.1.7 on 2019-09-04 12:15

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import uuid


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='TwilioMessage',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('message_sid', models.CharField(blank=True, max_length=512, null=True, unique=True)),
                ('type', models.CharField(choices=[('incoming', 'incoming'), ('outgoing', 'outgoing')], max_length=32)),
                ('status', models.CharField(blank=True, choices=[('accepted', 'Accepted'), ('queued', 'Queued'), ('sent', 'Sent'), ('delivered', 'Delivered'), ('undelivered', 'Undelivered'), ('failed', 'Failed'), ('received', 'Received')], max_length=32)),
                ('from_number', models.CharField(max_length=255)),
                ('to_number', models.CharField(max_length=255)),
                ('original_body', models.TextField()),
                ('body', models.TextField()),
                ('exception_message', models.TextField()),
                ('creation_datetime', models.DateTimeField(default=django.utils.timezone.now)),
                ('update_datetime', models.DateTimeField(auto_now=True)),
                ('recipient', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='twilio_messages', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'Twilio Message',
                'verbose_name_plural': 'Twilio Messages',
            },
        ),
    ]
