# Generated by Django 2.2.6 on 2019-10-28 13:53

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('django_sms_toolkit', '0002_alter_model_options'),
    ]

    operations = [
        migrations.AlterField(
            model_name='twiliomessage',
            name='recipient',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='twilio_messages', to=settings.AUTH_USER_MODEL),
        ),
    ]
