# Generated by Django 2.1.7 on 2019-10-09 12:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_sms_toolkit', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='twiliomessage',
            options={'ordering': ['-creation_datetime'], 'verbose_name': 'Twilio Message', 'verbose_name_plural': 'Twilio Messages'},
        ),
        migrations.AlterField(
            model_name='twiliomessage',
            name='status',
            field=models.CharField(blank=True, choices=[('rejected', 'rejected'), ('accepted', 'accepted'), ('queued', 'queued'), ('sent', 'sent'), ('delivered', 'delivered'), ('undelivered', 'undelivered'), ('failed', 'failed'), ('received', 'received')], max_length=32),
        ),
    ]
